@@ -1,6 +1,6 @@
 /* -*- C -*-
  *  Mathlib : A C Library of Special Functions
- *  Copyright (C) 1998-2011  The R Core Team
+ *  Copyright (C) 1998-2013  The R Core Team
  *  Copyright (C) 2004       The R Foundation
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -32,15 +32,16 @@
 #define RMATH_H
 
 /* Note that on some systems we need to include math.h before the
-   defines below, to avoid redefining ftrunc */
+   defines below. */
 #ifndef NO_C_HEADERS
+# define __STDC_WANT_IEC_60559_TYPES_EXT__ 1
 # include <math.h>
 #endif
 
 /*-- Mathlib as part of R --  define this for standalone : */
 /* #undef MATHLIB_STANDALONE */
 
-#define R_VERSION_STRING "2.15.3"
+#define R_VERSION_STRING "3.1.0"
 
 #ifndef HAVE_EXPM1
 # define HAVE_EXPM1 1
@@ -67,14 +68,16 @@ double  Rlog1p(double);
 
 	/* Undo SGI Madness */
 
-#ifdef ftrunc
-# undef ftrunc
-#endif
-#ifdef qexp
-# undef qexp
-#endif
-#ifdef qgamma
-# undef qgamma
+#ifdef __sgi
+# ifdef ftrunc
+#  undef ftrunc
+# endif
+# ifdef qexp
+#  undef qexp
+# endif
+# ifdef qgamma
+#  undef qgamma
+# endif
 #endif
 
 
@@ -169,6 +172,10 @@ double  Rlog1p(double);
 #endif
 
 
+#ifndef M_LN_2PI
+#define M_LN_2PI	1.837877066409345483560659472811	/* log(2*pi) */
+#endif
+
 #ifndef M_LN_SQRT_PI
 #define M_LN_SQRT_PI	0.572364942924700087071713675677	/* log(sqrt(pi))
 								   == log(pi)/2 */
@@ -180,7 +187,8 @@ double  Rlog1p(double);
 #endif
 
 #ifndef M_LN_SQRT_PId2
-#define M_LN_SQRT_PId2	0.225791352644727432363097614947	/* log(sqrt(pi/2)) */
+#define M_LN_SQRT_PId2	0.225791352644727432363097614947	/* log(sqrt(pi/2))
+								   == log(pi/2)/2 */
 #endif
 
 
@@ -197,7 +205,7 @@ double  Rlog1p(double);
 #endif
 
 
-#ifndef MATHLIB_STANDALONE
+#if !defined(MATHLIB_STANDALONE) && !defined(R_NO_REMAP_RMATH)
 #define bessel_i	Rf_bessel_i
 #define bessel_j	Rf_bessel_j
 #define bessel_k	Rf_bessel_k
@@ -222,6 +230,7 @@ double  Rlog1p(double);
 #define dlogis		Rf_dlogis
 #define dnbeta		Rf_dnbeta
 #define dnbinom		Rf_dnbinom
+#define dnbinom_mu	Rf_dnbinom_mu
 #define dnchisq		Rf_dnchisq
 #define dnf		Rf_dnf
 #define dnorm4		Rf_dnorm4
@@ -266,6 +275,7 @@ double  Rlog1p(double);
 #define plogis		Rf_plogis
 #define pnbeta		Rf_pnbeta
 #define pnbinom		Rf_pnbinom
+#define pnbinom_mu     	Rf_pnbinom_mu
 #define pnchisq		Rf_pnchisq
 #define pnf		Rf_pnf
 #define pnorm5		Rf_pnorm5
@@ -294,6 +304,7 @@ double  Rlog1p(double);
 #define qlogis		Rf_qlogis
 #define qnbeta		Rf_qnbeta
 #define qnbinom		Rf_qnbinom
+#define qnbinom_mu     	Rf_qnbinom_mu
 #define qnchisq		Rf_qnchisq
 #define qnf		Rf_qnf
 #define qnorm5		Rf_qnorm5
@@ -334,10 +345,9 @@ double  Rlog1p(double);
 #define trigamma	Rf_trigamma
 #endif
 
-#define	rround	fround
-#define	prec	fprec
-#undef trunc
-#define	trunc	ftrunc
+#define dnorm dnorm4
+#define pnorm pnorm5
+#define qnorm qnorm5
 
 #ifdef  __cplusplus
 extern "C" {
@@ -359,10 +369,6 @@ void	get_seed(unsigned int *, unsigned int *);
 
 	/* Normal Distribution */
 
-#define pnorm pnorm5
-#define qnorm qnorm5
-#define dnorm dnorm4
-
 double	dnorm(double, double, double, int);
 double	pnorm(double, double, double, int, int);
 double	qnorm(double, double, double, int, int);
@@ -595,6 +601,18 @@ double	ftrunc(double);
 double  log1pmx(double); /* Accurate log(1+x) - x, {care for small x} */
 double  lgamma1p(double);/* accurate log(gamma(x+1)), small x (0 < x < 0.5) */
 
+/* More accurate cos(pi*x), sin(pi*x), tan(pi*x)
+
+   In future these declarations could clash with system headers if
+   someone had already included math.h with
+   __STDC_WANT_IEC_60559_TYPES_EXT__ defined.
+   We can add a check for that via the value of
+   __STDC_IEC_60559_FUNCS__ (>= 201ymmL, exact value not yet known).
+*/
+double cospi(double);
+double sinpi(double);
+double tanpi(double);
+
 /* Compute the log of a sum or difference from logs of terms, i.e.,
  *
  *     log (exp (logx) + exp (logy))
@@ -606,8 +624,6 @@ double  logspace_add(double logx, double logy);
 double  logspace_sub(double logx, double logy);
 
 
-
-
 /* ----------------- Private part of the header file ------------------- */
 
 	/* old-R Compatibility */
